==> jc-1.4.0.tar.gz: polyglot/util/UniqueID.h <==
// public class polyglot.util.UniqueID

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9bc49ed94f6e3d31 polyglot_util_UniqueID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_UniqueID_H_
#define _JC_polyglot_util_UniqueID_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_UniqueID$sub_refs	_jc_polyglot_util_UniqueID$sub_refs;
typedef struct _jc_polyglot_util_UniqueID$sub_nonrefs	_jc_polyglot_util_UniqueID$sub_nonrefs;
typedef struct _jc_polyglot_util_UniqueID$refs	_jc_polyglot_util_UniqueID$refs;
typedef struct _jc_polyglot_util_UniqueID$nonrefs	_jc_polyglot_util_UniqueID$nonrefs;
typedef struct _jc_polyglot_util_UniqueID$object	_jc_polyglot_util_UniqueID$object;

typedef struct _jc_polyglot_util_UniqueID$fields_struct	_jc_polyglot_util_UniqueID$fields_struct;
typedef const struct _jc_polyglot_util_UniqueID$vmethods	_jc_polyglot_util_UniqueID$vmethods;
typedef const struct _jc_polyglot_util_UniqueID$vtable	_jc_polyglot_util_UniqueID$vtable;
typedef const struct _jc_polyglot_util_UniqueID$vtype	_jc_polyglot_util_UniqueID$vtype;

// Class fields structure
struct _jc_polyglot_util_UniqueID$fields_struct {
	jint	count;
	jint	icount;
};
extern _jc_polyglot_util_UniqueID$fields_struct _jc_polyglot_util_UniqueID$class_fields;

// Constructors
extern void _jc_polyglot_util_UniqueID$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_UniqueID$object *);

// Static methods
extern void _jc_polyglot_util_UniqueID$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_UniqueID$method$newID$f257875d0e575548(_jc_env *, struct _jc_java_lang_String$object *);
extern jint _jc_polyglot_util_UniqueID$method$newIntID$f247f8847a796e85(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_util_UniqueID$vmethods {
};

// Vtable
struct _jc_polyglot_util_UniqueID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_UniqueID$vmethods	polyglot_util_UniqueID;
};

// Vtype
struct _jc_polyglot_util_UniqueID$vtype {
	_jc_type			type;
	_jc_polyglot_util_UniqueID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_UniqueID$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_UniqueID$refs {
    _jc_polyglot_util_UniqueID$sub_refs	polyglot_util_UniqueID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_UniqueID$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_UniqueID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_UniqueID$sub_nonrefs	polyglot_util_UniqueID;
};

// Object instance structure
struct _jc_polyglot_util_UniqueID$object {
	_jc_polyglot_util_UniqueID$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_UniqueID$vtype	*vtype;
	_jc_polyglot_util_UniqueID$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_UniqueID$vtype _jc_polyglot_util_UniqueID$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_UniqueID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_UniqueID$class_object;

#endif	/* _JC_polyglot_util_UniqueID_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/UniqueID.h <==
// public class polyglot.util.UniqueID

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9bc49ed94f6e3d31 polyglot_util_UniqueID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_UniqueID_H_
#define _JC_polyglot_util_UniqueID_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_UniqueID$sub_refs	_jc_polyglot_util_UniqueID$sub_refs;
typedef struct _jc_polyglot_util_UniqueID$sub_nonrefs	_jc_polyglot_util_UniqueID$sub_nonrefs;
typedef struct _jc_polyglot_util_UniqueID$refs	_jc_polyglot_util_UniqueID$refs;
typedef struct _jc_polyglot_util_UniqueID$nonrefs	_jc_polyglot_util_UniqueID$nonrefs;
typedef struct _jc_polyglot_util_UniqueID$object	_jc_polyglot_util_UniqueID$object;

typedef struct _jc_polyglot_util_UniqueID$fields_struct	_jc_polyglot_util_UniqueID$fields_struct;
typedef const struct _jc_polyglot_util_UniqueID$vmethods	_jc_polyglot_util_UniqueID$vmethods;
typedef const struct _jc_polyglot_util_UniqueID$vtable	_jc_polyglot_util_UniqueID$vtable;
typedef const struct _jc_polyglot_util_UniqueID$vtype	_jc_polyglot_util_UniqueID$vtype;

// Class fields structure
struct _jc_polyglot_util_UniqueID$fields_struct {
	jint	count;
	jint	icount;
};
extern _jc_polyglot_util_UniqueID$fields_struct _jc_polyglot_util_UniqueID$class_fields;

// Constructors
extern void _jc_polyglot_util_UniqueID$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_UniqueID$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_polyglot_util_UniqueID$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_UniqueID$method$newID$f257875d0e575548(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_UniqueID$method$newIntID$f247f8847a796e85(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_UniqueID$vmethods {
};

// Vtable
struct _jc_polyglot_util_UniqueID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_UniqueID$vmethods	polyglot_util_UniqueID;
};

// Vtype
struct _jc_polyglot_util_UniqueID$vtype {
	_jc_type			type;
	_jc_polyglot_util_UniqueID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_UniqueID$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_UniqueID$refs {
    _jc_polyglot_util_UniqueID$sub_refs	polyglot_util_UniqueID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_UniqueID$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_UniqueID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_UniqueID$sub_nonrefs	polyglot_util_UniqueID;
};

// Object instance structure
struct _jc_polyglot_util_UniqueID$object {
	_jc_polyglot_util_UniqueID$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_UniqueID$vtype	*vtype;
	_jc_polyglot_util_UniqueID$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_UniqueID$vtype _jc_polyglot_util_UniqueID$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_UniqueID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_UniqueID$class_object;

#endif	/* _JC_polyglot_util_UniqueID_H_ */
